//---------------------------------------------------------------------------------
/// \file	MyFunction.cpp
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	This is the simplest possible example of how to write a mel command
///			that can be added into Maya via a plugin. You can call the command 
///			from mel by typing, "SimpleCommand". This simply executes a mel call 
///			via MGlobal::executeCommand to create a sphere.
///	
//---------------------------------------------------------------------------------

#ifdef WIN32
	#define NT_PLUGIN
#endif

// include any maya headers we need.
#include "MyFunction.h"

MSyntax MyFunction::newSyntax() {

	MSyntax syntax;

	// specify syntax for the command here....

	syntax.addFlag("-h","-help");

	syntax.addFlag("-x","-xcoord",MSyntax::kLong);
	syntax.addFlag("-y","-ycoord",MSyntax::kLong);
	syntax.addFlag("-f","-file",MSyntax::kString);

	return syntax;
}

//---------------------------------------------------------------------------------
/// \brief	this function is called by maya to return a new instance of our mel function
/// \return	the new mel command object
///
void* MyFunction::creator() {
	return new MyFunction;
}


//---------------------------------------------------------------------------------
/// \brief	This function impliments our very first simple command plugin.
/// \param	args - the argument list that was passes to the command from MEL
/// \return	MS::kSuccess - command succeeded
///			MS::kFailure - command failed (returning this value will cause the
///         	           MEL script that is being run to terminate unless the
///         	           error is caught using a "catch" statement.
///
MStatus MyFunction::doIt( const MArgList& args )

{
	// the return status
	MStatus stat = MS::kSuccess;


	MArgDatabase parser(syntax(),args,&stat);

	// return if argument parsing failed...
	if( stat != MS::kSuccess )
	{
		// error!!
		return stat;
	}

	if( parser.isFlagSet("-h") )
	{
		MGlobal::displayInfo("some help....");
		return MS::kSuccess;
	}

	if( !parser.isFlagSet("-x") ||
		!parser.isFlagSet("-y") ||
		!parser.isFlagSet("-f") )
	{
		MGlobal::displayError("missing required param");
		return MS::kSuccess;
	}

	// all the flags set....
	int px,py;
	MString filename;

	parser.getFlagArgument("-x",0,px);
	parser.getFlagArgument("-y",0,py);
	parser.getFlagArgument("-f",0,filename);

	MImage image;

	if( image.readFromFile(filename) !=
			MS::kSuccess )
	{
		MGlobal::displayError("Could not load image");
		return MS::kFailure;
	}

	unsigned int w,h;

	image.getSize(w,h);

	if( static_cast<int>(w)<px || static_cast<int>(h)<py ) {

		MGlobal::displayError("coords out of range");
		return MS::kFailure;
	}

	const unsigned char* pix =
		image.pixels() + (w*py*4 + 4*px);

	MIntArray result;

	result.append(pix[0]); // r
	result.append(pix[1]); // g
	result.append(pix[2]); // b
	result.append(pix[3]); // a

	setResult(result);

	//  int $pix[] = `myFunction`;

	return stat;
}







